==> jcquery-1.2.2.tgz: package/$.js <==
/**
 * A helper returning constructor class of given argument.
 */
export const $classOf = (/** @type {any} */ arg) => arg?.constructor

/**
 * A helper that checks if the given argument is of type `string`.
 *
 * @returns {arg is string}
 */
export const $isString = (/** @type {any} */ arg) => $classOf(arg) === String

/**
 * A helper that checks if the given argument is of type `number`.
 *
 * @returns {arg is number}
 */
export const $isNumber = (/** @type {any} */ arg) => $classOf(arg) === Number

/**
 * A helper that checks if the given argument is of type `Record<string, any>`.
 *
 * @returns {arg is Record<string, any>}
 */
export const $isObject = (/** @type {any} */ arg) => $classOf(arg) === Object

/**
 * A helper that checks if the given argument is of type `Array`.
 */
export const $isArray = Array.isArray

/**
 * Replacement for the `in` operator (not to be confused with the `for-in` loop) that works properly.
 */
export const $in = (/** @type {any} */ key, /** @type {any} */ ref) =>
  ($isString(key) || $isNumber(key)) && Object.hasOwnProperty.call(ref ?? Object, key)

/**
 * A helper that checks the equality of the given arguments.
 *
 * @returns {boolean}
 */
export const $eq = (/** @type {any} */ x, /** @type {any} */ y) => {
  if (x === y) {
    return true
  }

  const classOfX = $classOf(x)

  if (classOfX === $classOf(y)) {
    if (classOfX === Number) {
      return (isNaN(x) && isNaN(y)) || +x === +y
    }

    if (classOfX === Date) {
      return +x === +y
    }

    if (classOfX === String || classOfX === RegExp) {
      return '' + x === '' + y
    }

    if (classOfX === Array) {
      return x.length === y.length && x.every((/** @type {any} */ item, /** @type {number} */ index) => $eq(item, y[index]))
    }

    if (classOfX === Object) {
      const keysOfX = Object.keys(x)
      return keysOfX.length === Object.keys(y).length && keysOfX.every(key => $eq(x[key], y[key]))
    }

    if (classOfX === Set || classOfX === Map) {
      if (x.size !== y.size) {
        return false
      }
      const xa = [...x]
      const ya = [...y]
      return xa.every(xv => ya.find(yv => $eq(xv, yv)))
    }
  }

  return false
}

/**
 * *Attributes* of the created or modified element set by `setAttribute` or `setAttributeNS`.
 *
 * @typedef {Record<string, string | number | boolean>} $Attributes
 */

/**
 * *Properties* to set on the created or modified element.
 *
 * @typedef {Record<string, any>} $Properties
 */

/**
 * *Item* to append to the created or modified element.
 *
 * @typedef {HTMLElement | Text | SVGElement | string | number | $Config} $Item
 */

/**
 * @typedef {{
 *   e:  keyof HTMLElementTagNameMap | HTMLElement;
 *   a?: $Attributes;
 *   p?: $Properties;
 *   i?: $Item[];
 * }} $Config
 */

/**
 * ExtJS like, lightweight helper for creating and modifying HTML elements.
 *
 * @type {{
 *   <T extends keyof HTMLElementTagNameMap>(config: $Config & { e: T; }): HTMLElementTagNameMap[T];
 *   <E extends HTMLElement>(config: $Config & { e: E; }): E;
 *   (config: $Config): HTMLElement;
 * }}
 *
 * @returns {HTMLElement}
 */
export const $ = (/** @type {$Config} */ { e, a = {}, p = {}, i = [] }) => {
  e = $isString(e) ? document.createElement(e) : e

  for (const attribute in a) {
    const value = a[attribute]
    if (value === true) {
      e.setAttribute(attribute, '')
    } else if (value === false) {
      e.removeAttribute(attribute)
    } else {
      // @ts-expect-error:
      e.setAttribute(attribute, value)
    }
  }

  for (const property in p) {
    const value = p[property]
    if (property in e && $isObject(value)) { // warning: $in cannot be used here!
      for (const key2 in value) {
        // @ts-expect-error:
        e[property][key2] = value[key2]
      }
    } else {
      // @ts-expect-error:
      e[property] = value
    }
  }

  for (const item of i) {
    e.appendChild(item instanceof HTMLElement || item instanceof SVGElement || item instanceof Text
      ? item
      : $isString(item) || $isNumber(item)
        // @ts-expect-error:
        ? document.createTextNode(item)
        : $(item))
  }

  return e
}

/**
 * Syntactic sugar for `$({ e, a, p i })`.
 *
 * @type {{
 *   <T extends keyof HTMLElementTagNameMap>(e: T, a?: $Attributes, p?: $Properties, ...i: $Item[]): HTMLElementTagNameMap[T];
 *   <E extends HTMLElement>(e: E, a?: $Attributes, p?: $Properties, ...i: $Item[]): E;
 *  (e: keyof HTMLElementTagNameMap | HTMLElement, a?: $Attributes, p?: $Properties, ...i: $Item[]): HTMLElement
 * }}
 *
 * @returns {HTMLElement}
 */
export const $$ = (
  /** @type {keyof HTMLElementTagNameMap | HTMLElement} */ e,
  /** @type {$Attributes} */ a = {},
  /** @type {$Properties} */ p = {},
  /** @type {$Item[]} */ ...i
) => $({ e, a, p, i })

/**
 * *Item* to append to the created or modified SVG element.
 *
 * @typedef {SVGElement | Text | string | number | $SVGConfig} $SVGItem
 */

/**
 * @typedef {{
 *   e:  keyof SVGElementTagNameMap | SVGElement;
 *   a?: $Attributes;
 *   p?: $Properties;
 *   i?: $SVGItem[];
 * }} $SVGConfig
 */

const /** @type {Record<string, string>} */ NS = {
  xlink: 'http://www.w3.org/1999/xlink'
}

/**
 * ExtJS like, lightweight helper for creating and modifying SVG elements.
 *
 * @type {{
 *   <T extends keyof SVGElementTagNameMap>(config: $SVGConfig & { e: T; }): SVGElementTagNameMap[T];
 *   <E extends SVGElement>(config: $SVGConfig & { e: E; }): E;
 *   (config: $SVGConfig): SVGElement;
 * }}
 *
 * @returns {SVGElement}
 */
export const $svg = (/** @type {$SVGConfig} */ { e, a = {}, p = {}, i = [] }) => {
  e = $isString(e) ? document.createElementNS('http://www.w3.org/2000/svg', e) : e

  for (const attribute in a) {
    const value = a[attribute]
    const indexOfColon = attribute.indexOf(':')

    if (indexOfColon >= 0) {
      const /** @type {string=} */ ns = NS[attribute.slice(0, indexOfColon)]

      if (ns != null) {
        const name = attribute.slice(indexOfColon + 1)

        if (value === true) {
          e.setAttributeNS(ns, name, '')
        } else if (value === false) {
          e.removeAttributeNS(ns, name)
        } else {
          e.setAttributeNS(ns, name, $isString(value) ? value : '' + value)
        }

        continue
      }
    }

    if (value === true) {
      e.setAttribute(attribute, '')
    } else if (value === false) {
      e.removeAttribute(attribute)
    } else {
      e.setAttribute(attribute, $isString(value) ? value : '' + value)
    }
  }

  for (const property in p) {
    const value = p[property]
    if (property in e && $isObject(value)) { // warning: $in cannot be used here!
      for (const key2 in value) {
        // @ts-expect-error:
        e[property][key2] = value[key2]
      }
    } else {
      // @ts-expect-error:
      e[property] = value
    }
  }

  for (const item of i) {
    e.appendChild(item instanceof SVGElement || item instanceof Text
      ? item
      : $isString(item) || $isNumber(item)
        // @ts-expect-error:
        ? document.createTextNode(item)
        : $svg(item))
  }

  return e
}

/**
 * A helper for creating `<svg><use>` elements.
 * Useful for reusing `SVGSymbolElement`s.
 */
export const $svgUse = (/** @type {string} */ id) => $svg({
  e: 'svg',
  i: [{
    e: 'use', a: { 'xlink:href': '#' + id }
  }]
})

/**
 * @typedef {{
 *   [attributeOrSelector: string]: string | number | $CSSRules;
 * }} $CSSRules
 */

/**
 * The `$CSS` format provides a hierarchical description of CSS rules.
 *
 * - Keys of sub-objects whose values are NOT objects are treated as CSS attribute, and values are treated as values of those CSS attributes; the concatenation of keys of all parent objects is a CSS rule.
 * - All keys ignore the part starting with a splitter (default: `$$`) sign until the end of the key (e.g. `src$$1` → `src`, `@font-face$$1` → `@font-face`).
 * - In keys specifying CSS attribute, all uppercase letters are replaced by lowercase letters with an additional `-` character preceding them (e.g. `fontFamily` → `font-family`).
 * - Commas in keys that makes a CSS rule cause it to “split” and create separate rules for each part (e.g. `{div:{margin:1,'.a,.b,.c':{margin:2}}}` → `div{margin:1}div.a,div.b,div.c{margin:2}`).
 * - Top-level keys that begin with `@` are not concatenated with sub-object keys.
 *
 * @typedef {{
 *   [selector: string]: $CSSRules;
 * }} $CSS
 */

const _css = (
  /** @type {$CSSRules} */ style,
  /** @type {string} */ prefix,
  /** @type {string[]} */ result,
  /** @type {(text: string) => string} */ split
) => {
  const /** @type {[$CSSRules | string[], string][]} */ queue = [[style, prefix]]

  while (queue.length > 0) {
    const [style2, prefix2] = queue.shift() ?? []

    if (style2 == null || prefix2 == null) {
      continue
    }

    if ($isArray(style2)) {
      result.push(prefix2, prefix2 !== '' ? '{' : '', style2.join(';'), prefix2 !== '' ? '}' : '')
    } else {
      const /** @type {[$CSSRules | string[], string][]} */ todo = []
      let /** @type {string[]} */ attributes = []
      let attributesPushed = false

      for (const key in style2) {
        const value = style2[key]

        if ($isString(value) || $isNumber(value)) {
          if (!attributesPushed) {
            attributesPushed = true
            attributes = []
            todo.push([attributes, prefix2])
          }

          attributes.push(`${split(key).replace(/([A-Z])/g, (_, letter) => '-' + letter.toLowerCase())}:${value}`)
        } else {
          attributesPushed = false

          const /** @type {string[]} */ newPrefix = []
          const keySplitted = key.split(',')

          for (const prefixItem of prefix2.split(',')) {
            for (const keyItem of keySplitted) {
              newPrefix.push(prefixItem + keyItem)
            }
          }

          todo.push([value, newPrefix.join(',')])
        }
      }

      queue.unshift(...todo)
    }
  }
}

/**
 * CSS-in-JS helper based on the `$CSS` format.
 * An iterative implementation that does not cause a stack overflow exception.
 */
export const $css = (/** @type {$CSS} */ style, /** @type {string} */ splitter = '$$') => {
  const split = (/** @type {string} */ text) => text.split(splitter)[0]
  const /** @type {string[]} */ result = []

  for (const key in style) {
    const value = style[key]

    if (key[0] === '@') {
      result.push(split(key) + '{')
      _css(value, '', result, split)
      result.push('}')
    } else {
      _css(value, split(key), result, split)
    }
  }

  return result.join('')
}

/**
 * A generic helper for syntax highlighting.
 *
 * @returns {$Item[]}
 */
export const $highlight = (
  /** @type {RegExp} */ pattern,
  /** @type {((chunk: string, index: number) => $Item)[]} */ highlighters,
  /** @type {string} */ innerText
) => {
  const /** @type {$Item[]} */ result = []

  innerText.split(pattern).forEach((chunk, index) => {
    index %= highlighters.length
    if (chunk != null) {
      result.push(highlighters[index](chunk, index))
    }
  })

  return result
}

/** @returns {string} */
const _locale = (
  /** @type {Record<string, Record<string, string | Record<string, string>>>} */ locales,
  /** @type {string} */ language,
  /** @type {string} */ text,
  /** @type {string} */ version
) => {
  // @ts-expect-error:
  const v = locales?.[language]?.[version]?.[text]
  if ($isString(v)) {
    return v
  }
  const t = locales?.[language]?.[text]
  return $isString(t) ? t : text
}

/**
 * Language translations helper.
 */
export const $locale = (
  /** @type {Record<string, Record<string, string | Record<string, string>>>} */ locales,
  /** @type {string} */ defaultLanguage,
  /** @type {readonly string[]} */ languages = navigator.languages
) => {
  for (const language of languages) {
    if ($in(language, locales)) {
      // @ts-expect-error:
      return _locale.bind(0, locales, language)
    }
  }

  // @ts-expect-error:
  return _locale.bind(0, locales, defaultLanguage)
}

==> jcquery-2.0.0.tgz: package/$.js <==
/**
 * A helper returning constructor class of given argument.
 */
export const $classOf = (/** @type {any} */ arg) => arg?.constructor

/**
 * A helper that checks if the given argument is of type `string`.
 *
 * @returns {arg is string}
 */
export const $isString = (/** @type {any} */ arg) => $classOf(arg) === String

/**
 * A helper that checks if the given argument is of type `number`.
 *
 * @returns {arg is number}
 */
export const $isNumber = (/** @type {any} */ arg) => $classOf(arg) === Number

/**
 * A helper that checks if the given argument is of type `Record<string, any>`.
 *
 * @returns {arg is Record<string, any>}
 */
export const $isObject = (/** @type {any} */ arg) => $classOf(arg) === Object

/**
 * A helper that checks if the given argument is of type `Array`.
 */
export const $isArray = Array.isArray

/**
 * Replacement for the `in` operator (not to be confused with the `for-in` loop) that works properly.
 */
export const $in = (/** @type {any} */ key, /** @type {any} */ ref) =>
  ($isString(key) || $isNumber(key)) && Object.hasOwnProperty.call(ref ?? Object, key)

/**
 * A helper that checks the equality of the given arguments.
 *
 * @returns {boolean}
 */
export const $eq = (/** @type {any} */ x, /** @type {any} */ y) => {
  if (x === y) {
    return true
  }

  const classOfX = $classOf(x)

  if (classOfX === $classOf(y)) {
    if (classOfX === Number) {
      return (isNaN(x) && isNaN(y)) || +x === +y
    }

    if (classOfX === Date) {
      return +x === +y
    }

    if (classOfX === String || classOfX === RegExp) {
      return '' + x === '' + y
    }

    if (classOfX === Array) {
      return x.length === y.length && x.every((/** @type {any} */ item, /** @type {number} */ index) => $eq(item, y[index]))
    }

    if (classOfX === Object) {
      const keysOfX = Object.keys(x)
      return keysOfX.length === Object.keys(y).length && keysOfX.every(key => $eq(x[key], y[key]))
    }

    if (classOfX === Set || classOfX === Map) {
      if (x.size !== y.size) {
        return false
      }
      const xa = [...x]
      const ya = [...y]
      return xa.every(xv => ya.find(yv => $eq(xv, yv)))
    }
  }

  return false
}

/**
 * *Keys* of the created or modified element.
 * Keys starting with `$` are treated as *$properties* to be set on the item being created or modified.
 * All other keys are treated as *attributes* to be set by `setAttribute` (or `setAttributeNS`).
 *
 * @typedef {Record<string, any>} $Keys
 */

/**
 * *Item* to append to the created or modified element.
 *
 * @typedef {HTMLElement | Text | SVGElement | string | number | $Config} $Item
 */

/**
 * @typedef {{
 *   e:  keyof HTMLElementTagNameMap | HTMLElement;
 *   k?: $Keys;
 *   i?: $Item[];
 * }} $Config
 */

/**
 * ExtJS like, lightweight helper for creating and modifying HTML elements.
 *
 * @type {{
 *   <T extends keyof HTMLElementTagNameMap>(config: $Config & { e: T; }): HTMLElementTagNameMap[T];
 *   <E extends HTMLElement>(config: $Config & { e: E; }): E;
 *   (config: $Config): HTMLElement;
 * }}
 *
 * @returns {HTMLElement}
 */
export const $ = (/** @type {$Config} */ { e, k = {}, i = [] }) => {
  e = $isString(e) ? document.createElement(e) : e

  for (const key in k) {
    const value = k[key]
    if (key.startsWith('$')) {
      const key1 = key.slice(1)
      if (key1 in e && $isObject(value)) { // warning: $in cannot be used here!
        for (const key2 in value) {
          // @ts-expect-error:
          e[key1][key2] = value[key2]
        }
      } else {
        // @ts-expect-error:
        e[key1] = value
      }
    } else {
      if (value === true) {
        e.setAttribute(key, '')
      } else if (value === false) {
        e.removeAttribute(key)
      } else {
        e.setAttribute(key, value)
      }
    }
  }

  for (const item of i) {
    e.appendChild(item instanceof HTMLElement || item instanceof SVGElement || item instanceof Text
      ? item
      : $isString(item) || $isNumber(item)
        // @ts-expect-error:
        ? document.createTextNode(item)
        : $(item))
  }

  return e
}

/**
 * Syntactic sugar for `$({ e, k, i })`.
 *
 * @type {{
 *   <T extends keyof HTMLElementTagNameMap>(e: T, k?: $Keys, ...i: $Item[]): HTMLElementTagNameMap[T];
 *   <E extends HTMLElement>(e: E, k?: $Keys, ...i: $Item[]): E;
 *  (e: keyof HTMLElementTagNameMap | HTMLElement, k?: $Keys, ...i: $Item[]): HTMLElement
 * }}
 *
 * @returns {HTMLElement}
 */
export const $$ = (
  /** @type {keyof HTMLElementTagNameMap | HTMLElement} */ e,
  /** @type {$Keys} */ k = {},
  /** @type {$Item[]} */ ...i
) => $({ e, k, i })

/**
 * *Item* to append to the created or modified SVG element.
 *
 * @typedef {SVGElement | Text | string | number | $SVGConfig} $SVGItem
 */

/**
 * @typedef {{
 *   e:  keyof SVGElementTagNameMap | SVGElement;
 *   k?: $Keys;
 *   i?: $SVGItem[];
 * }} $SVGConfig
 */

const /** @type {Record<string, string>} */ NS = {
  xlink: 'http://www.w3.org/1999/xlink'
}

/**
 * ExtJS like, lightweight helper for creating and modifying SVG elements.
 *
 * @type {{
 *   <T extends keyof SVGElementTagNameMap>(config: $SVGConfig & { e: T; }): SVGElementTagNameMap[T];
 *   <E extends SVGElement>(config: $SVGConfig & { e: E; }): E;
 *   (config: $SVGConfig): SVGElement;
 * }}
 *
 * @returns {SVGElement}
 */
export const $svg = (/** @type {$SVGConfig} */ { e, k = {}, i = [] }) => {
  e = $isString(e) ? document.createElementNS('http://www.w3.org/2000/svg', e) : e

  for (const key in k) {
    const value = k[key]

    if (key.startsWith('$')) {
      const key1 = key.slice(1)
      if (key1 in e && $isObject(value)) { // warning: $in cannot be used here!
        for (const key2 in value) {
          // @ts-expect-error:
          e[key1][key2] = value[key2]
        }
      } else {
        // @ts-expect-error:
        e[key1] = value
      }
    } else {
      const indexOfColon = key.indexOf(':')

      if (indexOfColon >= 0) {
        const /** @type {string=} */ ns = NS[key.slice(0, indexOfColon)]

        if (ns != null) {
          const name = key.slice(indexOfColon + 1)

          if (value === true) {
            e.setAttributeNS(ns, name, '')
          } else if (value === false) {
            e.removeAttributeNS(ns, name)
          } else {
            e.setAttributeNS(ns, name, $isString(value) ? value : '' + value)
          }

          continue
        }
      }

      if (value === true) {
        e.setAttribute(key, '')
      } else if (value === false) {
        e.removeAttribute(key)
      } else {
        e.setAttribute(key, $isString(value) ? value : '' + value)
      }
    }
  }

  for (const item of i) {
    e.appendChild(item instanceof SVGElement || item instanceof Text
      ? item
      : $isString(item) || $isNumber(item)
        // @ts-expect-error:
        ? document.createTextNode(item)
        : $svg(item))
  }

  return e
}

/**
 * A helper for creating `<svg><use>` elements.
 * Useful for reusing `SVGSymbolElement`s.
 */
export const $svgUse = (/** @type {string} */ id) => $svg({
  e: 'svg',
  i: [{
    e: 'use', k: { 'xlink:href': '#' + id }
  }]
})

/**
 * @typedef {{
 *   [attributeOrSelector: string]: string | number | $CSSRules;
 * }} $CSSRules
 */

/**
 * The `$CSS` format provides a hierarchical description of CSS rules.
 *
 * - Keys of sub-objects whose values are NOT objects are treated as CSS attribute, and values are treated as values of those CSS attributes; the concatenation of keys of all parent objects is a CSS rule.
 * - All keys ignore the part starting with a splitter (default: `$$`) sign until the end of the key (e.g. `src$$1` → `src`, `@font-face$$1` → `@font-face`).
 * - In keys specifying CSS attribute, all uppercase letters are replaced by lowercase letters with an additional `-` character preceding them (e.g. `fontFamily` → `font-family`).
 * - Commas in keys that makes a CSS rule cause it to “split” and create separate rules for each part (e.g. `{div:{margin:1,'.a,.b,.c':{margin:2}}}` → `div{margin:1}div.a,div.b,div.c{margin:2}`).
 * - Top-level keys that begin with `@` are not concatenated with sub-object keys.
 *
 * @typedef {{
 *   [selector: string]: $CSSRules;
 * }} $CSS
 */

const _css = (
  /** @type {$CSSRules} */ style,
  /** @type {string} */ prefix,
  /** @type {string[]} */ result,
  /** @type {(text: string) => string} */ split
) => {
  const /** @type {[$CSSRules | string[], string][]} */ queue = [[style, prefix]]

  while (queue.length > 0) {
    const [style2, prefix2] = queue.shift() ?? []

    if (style2 == null || prefix2 == null) {
      continue
    }

    if ($isArray(style2)) {
      result.push(prefix2, prefix2 !== '' ? '{' : '', style2.join(';'), prefix2 !== '' ? '}' : '')
    } else {
      const /** @type {[$CSSRules | string[], string][]} */ todo = []
      let /** @type {string[]} */ attributes = []
      let attributesPushed = false

      for (const key in style2) {
        const value = style2[key]

        if ($isString(value) || $isNumber(value)) {
          if (!attributesPushed) {
            attributesPushed = true
            attributes = []
            todo.push([attributes, prefix2])
          }

          attributes.push(`${split(key).replace(/([A-Z])/g, (_, letter) => '-' + letter.toLowerCase())}:${value}`)
        } else {
          attributesPushed = false

          const /** @type {string[]} */ newPrefix = []
          const keySplitted = key.split(',')

          for (const prefixItem of prefix2.split(',')) {
            for (const keyItem of keySplitted) {
              newPrefix.push(prefixItem + keyItem)
            }
          }

          todo.push([value, newPrefix.join(',')])
        }
      }

      queue.unshift(...todo)
    }
  }
}

/**
 * CSS-in-JS helper based on the `$CSS` format.
 * An iterative implementation that does not cause a stack overflow exception.
 */
export const $css = (/** @type {$CSS} */ style, /** @type {string} */ splitter = '$$') => {
  const split = (/** @type {string} */ text) => text.split(splitter)[0]
  const /** @type {string[]} */ result = []

  for (const key in style) {
    const value = style[key]

    if (key[0] === '@') {
      result.push(split(key) + '{')
      _css(value, '', result, split)
      result.push('}')
    } else {
      _css(value, split(key), result, split)
    }
  }

  return result.join('')
}

/**
 * A generic helper for syntax highlighting.
 *
 * @returns {$Item[]}
 */
export const $highlight = (
  /** @type {RegExp} */ pattern,
  /** @type {((chunk: string, index: number) => $Item)[]} */ highlighters,
  /** @type {string} */ innerText
) => {
  const /** @type {$Item[]} */ result = []

  innerText.split(pattern).forEach((chunk, index) => {
    index %= highlighters.length
    if (chunk != null) {
      result.push(highlighters[index](chunk, index))
    }
  })

  return result
}

/** @returns {string} */
const _locale = (
  /** @type {Record<string, Record<string, string | Record<string, string>>>} */ locales,
  /** @type {string} */ language,
  /** @type {string} */ text,
  /** @type {string} */ version
) => {
  // @ts-expect-error:
  const v = locales?.[language]?.[version]?.[text]
  if ($isString(v)) {
    return v
  }
  const t = locales?.[language]?.[text]
  return $isString(t) ? t : text
}

/**
 * Language translations helper.
 */
export const $locale = (
  /** @type {Record<string, Record<string, string | Record<string, string>>>} */ locales,
  /** @type {string} */ defaultLanguage,
  /** @type {readonly string[]} */ languages = navigator.languages
) => {
  for (const language of languages) {
    if ($in(language, locales)) {
      // @ts-expect-error:
      return _locale.bind(0, locales, language)
    }
  }

  // @ts-expect-error:
  return _locale.bind(0, locales, defaultLanguage)
}
